arsenal.iterextras package
==========================

Submodules
----------

arsenal.iterextras.fair module
------------------------------

.. automodule:: arsenal.iterextras.fair
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.iterextras.sort module
------------------------------

.. automodule:: arsenal.iterextras.sort
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.iterextras.sorted\_intersection module
----------------------------------------------

.. automodule:: arsenal.iterextras.sorted_intersection
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.iterextras.util module
------------------------------

.. automodule:: arsenal.iterextras.util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: arsenal.iterextras
   :members:
   :undoc-members:
   :show-inheritance:
